pub struct CarrierData {
pub code: Option<String>,
pub kind: Option<String>,
pub name: Option<String>,
}Expand description
Information about a carrier (ie. an airline, bus line, railroad, etc) that might be useful to display to an end-user.
This type is not used in any activity, and only used as part of another schema.
Fields
code: Option<String>The IATA designator of a carrier (airline, etc). For example, for American Airlines, the code is AA.
kind: Option<String>Identifies this as a kind of carrier (ie. an airline, bus line, railroad, etc). Value: the fixed string qpxexpress#carrierData.
name: Option<String>The long, full name of a carrier. For example: American Airlines.