pub struct CityData {
pub code: Option<String>,
pub country: Option<String>,
pub kind: Option<String>,
pub name: Option<String>,
}Expand description
Information about a city that might be useful to an end-user; typically the city of an airport.
This type is not used in any activity, and only used as part of another schema.
Fields
code: Option<String>The IATA character ID of a city. For example, for Boston this is BOS.
country: Option<String>The two-character country code of the country the city is located in. For example, US for the United States of America.
kind: Option<String>Identifies this as a city, typically with one or more airports. Value: the fixed string qpxexpress#cityData.
name: Option<String>The full name of a city. An example would be: New York.