pub struct Data {
pub aircraft: Option<Vec<AircraftData>>,
pub airport: Option<Vec<AirportData>>,
pub carrier: Option<Vec<CarrierData>>,
pub city: Option<Vec<CityData>>,
pub kind: Option<String>,
pub tax: Option<Vec<TaxData>>,
}Expand description
Detailed information about components found in the solutions of this response, including a trip’s airport, city, taxes, airline, and aircraft.
This type is not used in any activity, and only used as part of another schema.
Fields
aircraft: Option<Vec<AircraftData>>The aircraft that is flying between an origin and destination.
airport: Option<Vec<AirportData>>The airport of an origin or destination.
carrier: Option<Vec<CarrierData>>The airline carrier of the aircraft flying between an origin and destination. Allowed values are IATA carrier codes.
city: Option<Vec<CityData>>The city that is either the origin or destination of part of a trip.
kind: Option<String>Identifies this as QPX Express response resource, including a trip’s airport, city, taxes, airline, and aircraft. Value: the fixed string qpxexpress#data.
tax: Option<Vec<TaxData>>The taxes due for flying between an origin and a destination.