PassengerCounts

Struct PassengerCounts 

pub struct PassengerCounts {
    pub adult_count: Option<i32>,
    pub child_count: Option<i32>,
    pub infant_in_lap_count: Option<i32>,
    pub infant_in_seat_count: Option<i32>,
    pub kind: Option<String>,
    pub senior_count: Option<i32>,
}
The number and type of passengers. Unfortunately the definition of an infant, child, adult, and senior citizen varies across carriers and reservation systems.

This type is not used in any activity, and only used as part of another schema.

Fields

adult_count: Option<i32>

The number of passengers that are adults.

child_count: Option<i32>

The number of passengers that are children.

infant_in_lap_count: Option<i32>

The number of passengers that are infants travelling in the lap of an adult.

infant_in_seat_count: Option<i32>

The number of passengers that are infants each assigned a seat.

kind: Option<String>

Identifies this as a passenger count object, representing the number of passengers. Value: the fixed string qpxexpress#passengerCounts.

senior_count: Option<i32>

The number of passengers that are senior citizens.