pub struct TimeOfDayRange {
pub earliest_time: Option<String>,
pub kind: Option<String>,
pub latest_time: Option<String>,
}Expand description
Two times in a single day defining a time range.
This type is not used in any activity, and only used as part of another schema.
Fields
earliest_time: Option<String>The earliest time of day in HH:MM format.
kind: Option<String>Identifies this as a time of day range object, representing two times in a single day defining a time range. Value: the fixed string qpxexpress#timeOfDayRange.
latest_time: Option<String>The latest time of day in HH:MM format.