pub struct TripOptionsResponse {
pub data: Option<Data>,
pub kind: Option<String>,
pub request_id: Option<String>,
pub trip_option: Option<Vec<TripOption>>,
}Expand description
A QPX Express search response.
This type is not used in any activity, and only used as part of another schema.
Fields
data: Option<Data>Informational data global to list of solutions.
kind: Option<String>Identifies this as a QPX Express trip response object, which consists of zero or more solutions. Value: the fixed string qpxexpress#tripOptions.
request_id: Option<String>An identifier uniquely identifying this response.
trip_option: Option<Vec<TripOption>>A list of priced itinerary solutions to the QPX Express query.