pub struct TripsSearchResponse {
pub kind: Option<String>,
pub trips: Option<TripOptionsResponse>,
}Expand description
A QPX Express search response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- search trips (response)
Fields
kind: Option<String>Identifies this as a QPX Express API search response resource. Value: the fixed string qpxExpress#tripsSearch.
trips: Option<TripOptionsResponse>All possible solutions to the QPX Express search request.