pub struct LegInfo {Show 17 fields
pub aircraft: Option<String>,
pub arrival_time: Option<String>,
pub change_plane: Option<bool>,
pub connection_duration: Option<i32>,
pub departure_time: Option<String>,
pub destination: Option<String>,
pub destination_terminal: Option<String>,
pub duration: Option<i32>,
pub id: Option<String>,
pub kind: Option<String>,
pub meal: Option<String>,
pub mileage: Option<i32>,
pub on_time_performance: Option<i32>,
pub operating_disclosure: Option<String>,
pub origin: Option<String>,
pub origin_terminal: Option<String>,
pub secure: Option<bool>,
}Expand description
Information about a leg. (A leg is the smallest unit of travel, in the case of a flight a takeoff immediately followed by a landing at two set points on a particular carrier with a particular flight number.)
This type is not used in any activity, and only used as part of another schema.
Fields
aircraft: Option<String>The aircraft (or bus, ferry, railcar, etc) travelling between the two points of this leg.
arrival_time: Option<String>The scheduled time of arrival at the destination of the leg, local to the point of arrival.
change_plane: Option<bool>Whether you have to change planes following this leg. Only applies to the next leg.
connection_duration: Option<i32>Duration of a connection following this leg, in minutes.
departure_time: Option<String>The scheduled departure time of the leg, local to the point of departure.
destination: Option<String>The leg destination as a city and airport.
destination_terminal: Option<String>The terminal the flight is scheduled to arrive at.
duration: Option<i32>The scheduled travelling time from the origin to the destination.
id: Option<String>An identifier that uniquely identifies this leg in the solution.
kind: Option<String>Identifies this as a leg object. A leg is the smallest unit of travel, in the case of a flight a takeoff immediately followed by a landing at two set points on a particular carrier with a particular flight number. Value: the fixed string qpxexpress#legInfo.
meal: Option<String>A simple, general description of the meal(s) served on the flight, for example: “Hot meal”.
mileage: Option<i32>The number of miles in this leg.
on_time_performance: Option<i32>In percent, the published on time performance on this leg.
operating_disclosure: Option<String>Department of Transportation disclosure information on the actual operator of a flight in a code share. (A code share refers to a marketing agreement between two carriers, where one carrier will list in its schedules (and take bookings for) flights that are actually operated by another carrier.)
origin: Option<String>The leg origin as a city and airport.
origin_terminal: Option<String>The terminal the flight is scheduled to depart from.
secure: Option<bool>Whether passenger information must be furnished to the United States Transportation Security Administration (TSA) prior to departure.