pub struct TripOption {
pub id: Option<String>,
pub kind: Option<String>,
pub pricing: Option<Vec<PricingInfo>>,
pub sale_total: Option<String>,
pub slice: Option<Vec<SliceInfo>>,
}Expand description
Trip information.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>Identifier uniquely identifying this trip in a response.
kind: Option<String>Identifies this as a trip information object. Value: the fixed string qpxexpress#tripOption.
pricing: Option<Vec<PricingInfo>>Per passenger pricing information.
sale_total: Option<String>The total price for all passengers on the trip, in the form of a currency followed by an amount, e.g. USD253.35.
slice: Option<Vec<SliceInfo>>The slices that make up this trip’s itinerary.